%{?mingw_package_header}

%global pkgname LibRaw

Name:          mingw-%{pkgname}
Version:       0.18.5
Release:       1%{?dist}
Summary:       Library for reading RAW files obtained from digital photo cameras

# LibRaw base package is dual licensed (actually triple licensed LGPLv2+, CDDL, LibRaw Software License)
# LibRaw-%%{version}/internal/dcb_demosaicing.c is BSD (3 clause)
# LibRaw-demosaic-pack-GPL2 is GPLv2+
# LibRaw-demosaic-pack-GLP3 is GPLv3+
License:       (LGPLv2+ or CDDL) and GPLv2+ and GPLv3+ and BSD
BuildArch:     noarch
URL:           http://www.libraw.org
Source0:       http://www.libraw.org/data/%{pkgname}-%{version}.tar.gz
Source1:       http://www.libraw.org/data/%{pkgname}-demosaic-pack-GPL2-%{version}.tar.gz
Source2:       http://www.libraw.org/data/%{pkgname}-demosaic-pack-GPL3-%{version}.tar.gz
# Add missing -lwsock32
Patch0:        LibRaw_wsock32.patch
# Replace obsolete configure.ac macros
Patch1:        LibRaw_obsolete-macros.patch

BuildRequires: autoconf automake libtool

BuildRequires: mingw32-filesystem >= 95
BuildRequires: mingw32-gcc-c++
BuildRequires: mingw32-lcms2
BuildRequires: mingw32-jasper

BuildRequires: mingw64-filesystem >= 95
BuildRequires: mingw64-gcc-c++
BuildRequires: mingw64-lcms2
BuildRequires: mingw64-jasper

Provides: bundled(dcraw)


%description
MinGW Windows %{pkgname} library.


%package -n mingw32-%{pkgname}
Summary:       MinGW Windows %{pkgname} library

%description -n mingw32-%{pkgname}
%{summary}.


%package -n mingw32-%{pkgname}-static
Summary:       Static version of the MinGW Windows %{pkgname} library
Requires:      mingw32-%{pkgname} = %{version}-%{release}

%description -n mingw32-%{pkgname}-static
%{summary}.


%package -n mingw32-%{pkgname}-tools
Summary:       Tools for the MinGW Windows %{pkgname} library
Requires:      mingw32-%{pkgname} = %{version}-%{release}

%description -n mingw32-%{pkgname}-tools
%{summary}.


%package -n mingw64-%{pkgname}
Summary:       MinGW Windows %{pkgname} library

%description -n mingw64-%{pkgname}
%{summary}.


%package -n mingw64-%{pkgname}-static
Summary:       Static version of the MinGW Windows %{pkgname} library
Requires:      mingw64-%{pkgname} = %{version}-%{release}

%description -n mingw64-%{pkgname}-static
%{summary}.


%package -n mingw64-%{pkgname}-tools
Summary:       Tools for the MinGW Windows %{pkgname} library
Requires:      mingw64-%{pkgname} = %{version}-%{release}

%description -n mingw64-%{pkgname}-tools
%{summary}.


%{?mingw_debug_package}


%prep
%setup -q -a1 -a2 -n %{pkgname}-%{version}
%patch0 -p1
%patch1 -p1

# Rename licenses to avoid name conflicts in %%doc
mv LibRaw-demosaic-pack-GPL2-%{version}/LICENSE.txt LibRaw-demosaic-pack-GPL2-%{version}/LICENSE.GPL2
mv LibRaw-demosaic-pack-GPL3-%{version}/LICENSE.txt LibRaw-demosaic-pack-GPL3-%{version}/LICENSE.GPL3

# Remove executable bit on license files
chmod -x LICENSE.CDDL
chmod -x LICENSE.LGPL


%build
autoreconf -ifv
%mingw_configure --enable-jasper --enable-lcms --enable-demosaic-pack-gpl2 --enable-demosaic-pack-gpl3 CPPFLAGS=-DLIBRAW_NODLL
%mingw_make %{?_smp_mflags}


%install
%mingw_make install DESTDIR=%{buildroot}

# Delete *.la files
find %{buildroot} -name '*.la' -delete

# Install doc through %%doc
rm -rf %{buildroot}%{mingw32_datadir}
rm -rf %{buildroot}%{mingw64_datadir}


%files -n mingw32-%{pkgname}
%license LICENSE.CDDL LICENSE.LGPL COPYRIGHT
%license LibRaw-demosaic-pack-GPL2-%{version}/LICENSE.GPL2
%license LibRaw-demosaic-pack-GPL3-%{version}/LICENSE.GPL3
%{mingw32_bindir}/libraw-16.dll
%{mingw32_bindir}/libraw_r-16.dll
%{mingw32_includedir}/libraw/
%{mingw32_libdir}/libraw.dll.a
%{mingw32_libdir}/libraw_r.dll.a
%{mingw32_libdir}/pkgconfig/libraw.pc
%{mingw32_libdir}/pkgconfig/libraw_r.pc

%files -n mingw32-%{pkgname}-static
%{mingw32_libdir}/libraw_r.a
%{mingw32_libdir}/libraw.a

%files -n mingw32-%{pkgname}-tools
%{mingw32_bindir}/*.exe

%files -n mingw64-%{pkgname}
%license LICENSE.CDDL LICENSE.LGPL COPYRIGHT
%license LibRaw-demosaic-pack-GPL2-%{version}/LICENSE.GPL2
%license LibRaw-demosaic-pack-GPL3-%{version}/LICENSE.GPL3
%{mingw64_bindir}/libraw-16.dll
%{mingw64_bindir}/libraw_r-16.dll
%{mingw64_includedir}/libraw/
%{mingw64_libdir}/libraw.dll.a
%{mingw64_libdir}/libraw_r.dll.a
%{mingw64_libdir}/pkgconfig/libraw.pc
%{mingw64_libdir}/pkgconfig/libraw_r.pc

%files -n mingw64-%{pkgname}-static
%{mingw64_libdir}/libraw_r.a
%{mingw64_libdir}/libraw.a

%files -n mingw64-%{pkgname}-tools
%{mingw64_bindir}/*.exe


%changelog
* Fri Sep 22 2017 Sandro Mani <manisandro@gmail.com> - 0.18.5-1
- Update to 0.18.5

* Wed Sep 13 2017 Sandro Mani <manisandro@gmail.com> - 0.18.4-1
- Update to 0.18.4

* Sat Sep 09 2017 Sandro Mani <manisandro@gmail.com> - 0.18.3-1
- Update to 0.18.3

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.18.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun Jul 09 2017 Sandro Mani <manisandro@gmail.com> - 0.18.2-3
- Rebuild

* Sat Jul 01 2017 Sandro Mani <manisandro@gmail.com> - 0.18.2-2
- Rebuild

* Mon Mar 13 2017 Sandro Mani <manisandro@gmail.com> - 0.18.2-1
- Update to 0.18.2

* Mon Feb 13 2017 Sandro Mani <manisandro@gmail.com> - 0.18.1-1
- Update to 0.18.1

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.18.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sun Jan 01 2017 Sandro Mani <manisandro@gmail.com> - 0.18.0-1
- Update to 0.18.0

* Wed Nov 23 2016 Michael Cronenworth <mike@cchtml.com> - 0.17.2-2
- Rebuilt for mingw-jasper update

* Thu May 19 2016 Sandro Mani <manisandro@gmail.com> - 0.17.2-1
- Update to 0.17.2

* Wed May 11 2016 Sandro Mani <manisandro@gmail.com> - 0.17.1-3
- Add dcraw_narrowing.patch to fix GCC6 FTBFS

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.17.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Nov 30 2015 Sandro Mani <manisandro@gmail.com> - 0.17.1-1
- Update to 0.17.1

* Sat Aug 22 2015 Sandro Mani <manisandro@gmail.com> - 0.17.0-1
- Update to 0.17.0

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.16.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun May 17 2015 Sandro Mani <manisandro@gmail.com> - 0.16.2-1
- Update to 0.16.2

* Mon May 11 2015 Sandro Mani <manisandro@gmail.com> - 0.16.1-1
- Update to 0.16.1

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.16.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Jan 22 2014 Sandro Mani <manisandro@gmail.com> - 0.16.0-1
- Update to 0.16.0

* Tue Jan 14 2014 Sandro Mani <manisandro@gmail.com> - 0.15.4-4
- Actually remove executable permissions from the problematic LICENSE files

* Mon Jan 13 2014 Sandro Mani <manisandro@gmail.com> - 0.15.4-3
- Add patch to replace obsolete configure.ac macros
- Remove executable permissions from LICENSE files

* Wed Jan 08 2014 Sandro Mani <manisandro@gmail.com> - 0.15.4-2
- Fix license

* Sat Dec 28 2013 Sandro Mani <manisandro@gmail.com> - 0.15.4-1
- Initial package
